@@ -1,7 +1,8 @@
 from time import sleep
+from colorama import Fore
 
 
-def bar(progress, total, icon='█', begin='Downloading', show_percent=True):
+def bar(progress, total, icon='█', begin='Downloading', show_percent=True, colour=Fore.WHITE):
     '''
     Be sure to print a ('\\n') after running the bar function!
     You can find out why ;)
@@ -10,9 +11,10 @@ def bar(progress, total, icon='█', begin='Downloading', show_percent=True):
     some = percent - 50
     bar = icon * int(percent) + '-' * (50 - int(percent))
     if show_percent == True:
-        print(f"\r{begin} |{bar}| {50 + percent:.2f}%", end="")
+        print(colour + f"\r{begin} |{bar}| {50 + percent:.2f}%", end="")
     else:
-        print(f"\r{begin} |{bar}|", end="")
+        print(colour + f"\r{begin} |{bar}|", end="")
+    
 
 def rotate(begin = 'Downloading', sleep_value = 0.1):
     list = ['|', '/', '-', '\\']
@@ -20,4 +22,5 @@ def rotate(begin = 'Downloading', sleep_value = 0.1):
     for i in list:
         sleep(sleep_value)
         ting = i
-        print(f'\r{begin} {ting}', end='\r')
\ No newline at end of file
+        print(f'\r{begin} {ting}', end='\r')
+Fore.RESET
